<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */

if (!isset($GLOBALS['Piwik_socialUrl'])) {
    // Note: the key of the array should have max 3 elements eg. sub.domain.ext
    $GLOBALS['Piwik_socialUrl'] = array(

        // Facebook
        'facebook.com'         => 'Facebook',
        'fb.me'                => 'Facebook',

        // Ozone
        'qzone.qq.com'         => 'Qzone',

        // Haboo
        'habbo.com'            => 'Haboo',

        // Twitter
        'twitter.com'          => 'Twitter',
        't.co'                 => 'Twitter',

        // Renren
        'renren.com'           => 'Renren',

        // Windows Live Spaces
        'login.live.com'       => 'Windows Live Spaces',

        // LinkedIn
        'linkedin.com'         => 'LinkedIn',

        // Bebo
        'bebo.com'             => 'Bebo',

        // Vkontakte
        'vk.com'               => 'Vkontakte',
        'vkontakte.ru'         => 'Vkontakte',

        // Tagged
        'login.tagged.com'     => 'Tagged',

        // Orkut
        'orkut.com'            => 'Orkut',

        // Myspace
        'myspace.com'          => 'Myspace',

        // Frinedster
        'friendster.com'       => 'Friendster',

        // Badoo
        'badoo.com'            => 'Badoo',

        // hi5
        'hi5.com'              => 'hi5',

        // Netlog
        'netlog.com'           => 'Netlog',

        // Flixster
        'flixster.com'         => 'Flixster',

        // MyLife
        'mylife.ru'            => 'MyLife',

        // Classmates.com
        'classmates.com'       => 'Classmates.com',

        // Github
        'github.com'           => 'Github',

        // Google+
        'url.google.com'       => 'Google%2B',

        // douban
        'douban.com'           => 'douban',

        // Odnoklassniki
        'odnoklassniki.ru'     => 'Odnoklassniki',

        // Viadeo
        'viadeo.com'           => 'Viadeo',

        // Flickr
        'flickr.com'           => 'Flickr',

        // WeeWorld
        'weeworld.com'         => 'WeeWorld',

        // Last.fm
        'last.fm'              => 'Last.fm',
        'lastfm.ru'            => 'Last.fm',
        'lastfm.de'            => 'Last.fm',
        'lastfm.es'            => 'Last.fm',
        'lastfm.fr'            => 'Last.fm',
        'lastfm.it'            => 'Last.fm',
        'lastfm.jp'            => 'Last.fm',
        'lastfm.pl'            => 'Last.fm',
        'lastfm.com.br'        => 'Last.fm',
        'lastfm.se'            => 'Last.fm',
        'lastfm.com.tr'        => 'Last.fm',

        // MyHeritage
        'myheritage.com'       => 'MyHeritage',

        // Xanga
        'xanga.com'            => 'Xanga',

        // Mixi
        'mixi.jp'              => 'Mixi',

        // Cyworld
        'global.cyworld.com'   => 'Cyworld',

        // Gaia Online
        'gaiaonline.com'       => 'Gaia Online',

        // Skyrock
        'skyrock.com'          => 'Skyrock',

        // BlackPlanet
        'blackplanet.com'      => 'BlackPlanet',

        // myYearbook
        'myyearbook.com'       => 'myYearbook',

        // Fotolog
        'fotolog.com'          => 'Fotolog',

        // Friends Reunited
        'friendsreunited.com'  => 'Friends Reunited',

        // LiveJournal
        'livejournal.ru'       => 'LiveJournal',
        'livejournal.com'      => 'LiveJournal',

        // StudiVZ/MeinVZ
        'studivz.net'          => 'StudiVZ',
        'meinvz.net'           => 'MeinVZ',

        // StackOverflow
        'stackoverflow.com'    => 'StackOverflow',

        // Sonico.com
        'sonico.com'           => 'Sonico.com',

        // Pinterest
        'pinterest.com'        => 'Pinterest',

        // Plaxo
        'plaxo.com'            => 'Plaxo',

        // Geni.com
        'geni.com'             => 'Geni.com',

        // Tuenti
        'tuenti.com'           => 'Tuenti',

        // XING
        'xing.com'             => 'XING',

        // Taringa!
        'taringa.net'          => 'Taringa!',

        // Nasza-klasa.pl
        'nk.pl'                => 'Nasza-klasa.pl',

        // StumbleUpon
        'stumbleupon.com'      => 'StumbleUpon',

        // Sourceforge
        'sourceforge.net'      => 'SourceForge',

        // Hyves
        'hyves.nl'             => 'Hyves',

        // WAYN
        'wayn.com'             => 'WAYN',

        // Buzznet
        'buzznet.com'          => 'Buzznet',

        // Multiply
        'multiply.com'         => 'Multiply',

        // Foursquare
        'foursquare.com'    => 'Foursquare',

        // vkrugudruzei.ru
        'vkrugudruzei.ru'      => 'vkrugudruzei.ru',

        // my.mail.ru
        'my.mail.ru'           => 'my.mail.ru',

        //MoiKrug.ru
        'moikrug.ru'           => 'moikrug.ru',

        // Reddit
        'reddit.com'           => 'reddit',

        // HackerNews
        'news.ycombinator.com' => 'Hacker News',

        // Identi.ca
        'identi.ca'            => 'identi.ca',

        // Weibo
        'weibo.com'            => 'Weibo',
        't.cn'                 => 'Weibo',

        // YouTube
        'youtube.com'          => 'YouTube',
        'youtu.be'             => 'YouTube',

        // Vimeo
        'vimeo.com'            => 'Vimeo',
        
        //tumblr
        'tumblr.com'           => 'tumblr',
    );
}
